# UpdateTaskStatus

The status of the task instance. 

## Enum

* `QUEUED` (value: `'Queued'`)

* `PROCESSING` (value: `'Processing'`)

* `PENDING` (value: `'Pending'`)

* `SUCCESS` (value: `'Success'`)

* `STOPPED` (value: `'Stopped'`)

* `ERROR` (value: `'Error'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


